@@ -217,6 +217,28 @@ def make_date_file_name(prefix: str = "", file_name: str = "", suffix: str = "")
     return time_str
 
 
+def delete_file(file_name: str) -> None:
+    """
+    The delete_file function deletes a file from the local directory.
+
+        Raises:
+            Exception if there is an error deleting the specified file.
+            This function will not catch any exceptions, so it should be
+            called within a try/except block.
+
+    :param file_name:str: Used to Specify the name of the file that will be deleted.
+    :return: None.
+
+    :doc-author: Julian M. Kleber
+    """
+
+    try:
+        os.remove(file_name)
+        logging.info("Deleted file %s", file_name)
+    except Exception as exc:
+        raise exc
+
+
 def get_grid_positions(rows: int, cols: int) -> List[Tuple[int, int]]:
     """
     The get_grid_positions function takes in the number of rows and columns in a grid,
